@@ -21,7 +21,7 @@
 #'  confidence limits for dS (and dL if `achromatic = TRUE`).
 #'
 #' @examples
-#' \dontrun{
+#' \donttest{
 #' data(sicalis)
 #' vm <- vismodel(sicalis, achromatic = "bt.dc")
 #' gr <- gsub("ind..", "", rownames(vm))
@@ -212,7 +212,7 @@ bootcoldist <- function(vismodeldata, by, boot.n = 1000, alpha = 0.95,
       tryCatch(suppressMessages(tmpbootcdfoo(z)),
         error = function(e) NULL
       )
-    })
+    }, future.seed = TRUE)
   })
 
   # get deltaS and name by group difference
