@@ -41,8 +41,9 @@
 triplot <- function(tridata, labels = TRUE, achro = TRUE, achrocol = "grey", achrosize = 0.8,
                     labels.cex = 1, out.lwd = 1, out.lcol = "black", out.lty = 1,
                     margins = c(1, 1, 2, 2), square = TRUE, gamut = FALSE, ...) {
-  oPar <- par("mar", "pty")
-  on.exit(par(oPar))
+
+  oldpar <- par(no.readonly = TRUE)
+  on.exit(par(oldpar))
 
   par(mar = margins)
 
